
## Install

pip install pip-gui-tools


## Run

pipuitool -p <PORT> -i <TARGET_PIP_INSTALL_PATH>

	-p (int): Port Number (optional)
	-b (str): Path Prefix ex. /pipui
	-i (str): Target Path of pip install. If not set, then no target is set (optional)
